@@ -1,38 +1,15 @@
 
 /*
-   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
-   All rights reserved.
+   SPDX-FileCopyrightText: 2003-2007 Clarence Dang <dang@kde.org>
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   1. Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-   2. Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   SPDX-License-Identifier: BSD-2-Clause
 */
 
-
 #ifndef KP_TOOL_TEXT_H
 #define KP_TOOL_TEXT_H
 
-
 #include "tools/selection/kpAbstractSelectionTool.h"
 
-
 class QKeyEvent;
 
 class kpColor;
@@ -43,7 +20,6 @@ class kpToolTextEnterCommand;
 class kpToolTextBackspaceCommand;
 class kpToolTextDeleteCommand;
 
-
 //
 // kpAbstractSelectionTool considers a drawing operation to be a mouse
 // drag that creates, moves or resize/scales a selection.
@@ -76,16 +52,15 @@ class kpToolTextDeleteCommand;
 //
 class kpToolText : public kpAbstractSelectionTool
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    kpToolText (kpToolSelectionEnvironment *environ, QObject *parent);
-    ~kpToolText () override;
+    kpToolText(kpToolSelectionEnvironment *environ, QObject *parent);
+    ~kpToolText() override;
 
-
-//
-// Text Command Handling
-//
+    //
+    // Text Command Handling
+    //
 
 private:
     /**
@@ -103,8 +78,7 @@ private:
      * might be split into 10 text insertion commands, each containing 1
      * character.
      */
-    void endTypingCommands ();
-
+    void endTypingCommands();
 
     /**
      * Ends the current text editing command by eventually calling
@@ -115,7 +89,7 @@ private:
      *            On function return, the pointed-to d->backspace.*Command
      *            pointer will point to a new kpToolTextBackspaceCommand.
      */
-    void addNewBackspaceCommand (kpToolTextBackspaceCommand **cmd);
+    void addNewBackspaceCommand(kpToolTextBackspaceCommand **cmd);
 
     /**
      * Ends the current text editing command by eventually calling
@@ -126,73 +100,61 @@ private:
      *            function return, the pointed-to d->delete.*Command pointer
      *            will point to a new kpToolTextDeleteCommand.
      */
-    void addNewDeleteCommand (kpToolTextDeleteCommand **cmd);
+    void addNewDeleteCommand(kpToolTextDeleteCommand **cmd);
 
-    void addNewEnterCommand (kpToolTextEnterCommand **cmd);
+    void addNewEnterCommand(kpToolTextEnterCommand **cmd);
 
-    void addNewInsertCommand (kpToolTextInsertCommand **cmd);
+    void addNewInsertCommand(kpToolTextInsertCommand **cmd);
 
-
-//
-// Drawing
-//
+    //
+    // Drawing
+    //
 
 protected:
-    kpAbstractSelectionContentCommand *newGiveContentCommand () const override;
-
-    QString nameOfCreateCommand () const override;
+    kpAbstractSelectionContentCommand *newGiveContentCommand() const override;
 
+    QString nameOfCreateCommand() const override;
 
 protected:
-    void setSelectionBorderForHaventBegunDraw () override;
-
+    void setSelectionBorderForHaventBegunDraw() override;
 
 public:
-    void begin () override;
-    void end () override;
-
+    void begin() override;
+    void end() override;
 
 public:
-    bool hasBegunText () const;
-    bool hasBegunShape () const override;
+    bool hasBegunText() const;
+    bool hasBegunShape() const override;
 
-
-//
-// Drawing - Beginning a Drag
-//
+    //
+    // Drawing - Beginning a Drag
+    //
 
 protected:
-    DrawType calculateDrawTypeInsideSelection () const override;
-
+    DrawType calculateDrawTypeInsideSelection() const override;
 
 public:
-    void cancelShape () override;
-
+    void cancelShape() override;
 
 public:
-    void endShape (const QPoint &thisPoint, const QRect &normalizedRect) override;
+    void endShape(const QPoint &thisPoint, const QRect &normalizedRect) override;
 
-
-//
-// Drawing - Operation Dispatching
-//
+    //
+    // Drawing - Operation Dispatching
+    //
 
 protected:
-    QVariant operation (DrawType drawType, Operation op,
-        const QVariant &data1 = QVariant (), const QVariant &data2 = QVariant ()) override;
+    QVariant operation(DrawType drawType, Operation op, const QVariant &data1 = QVariant(), const QVariant &data2 = QVariant()) override;
 
-
-//
-// Create
-//
+    //
+    // Create
+    //
 
 protected:
-    QString haventBegunDrawUserMessageCreate () const override;
-
+    QString haventBegunDrawUserMessageCreate() const override;
 
 protected:
-    void setSelectionBorderForBeginDrawCreate () override;
-
+    void setSelectionBorderForBeginDrawCreate() override;
 
 private:
     // Returns the suggested width/height of a click-created text box:
@@ -204,79 +166,64 @@ private:
     // <smallestMin> = the legal minimum width/height of the selection
     //
     // <docSize> = the width/height of the document
-    int calcClickCreateDimension (int mouseStart, int mouseEnd,
-        int preferredMin, int smallestMin,
-        int docSize);
-    bool shouldCreate (
-        bool drawAcceptedAsDrag,
-        const QPoint &accidentalDragAdjustedPoint,
-        const kpTextStyle &textStyle,
-        int *minimumWidthOut, int *minimumHeightOut,
-        bool *newDragHasBegun);
-protected:
-    bool drawCreateMoreSelectionAndUpdateStatusBar (
-        bool drawAcceptedAsDrag,
-        const QPoint &accidentalDragAdjustedPoint,
-        const QRect &normalizedRectIn) override;
-
-
-//
-// Move
-//
+    int calcClickCreateDimension(int mouseStart, int mouseEnd, int preferredMin, int smallestMin, int docSize);
+    bool shouldCreate(bool drawAcceptedAsDrag,
+                      const QPoint &accidentalDragAdjustedPoint,
+                      const kpTextStyle &textStyle,
+                      int *minimumWidthOut,
+                      int *minimumHeightOut,
+                      bool *newDragHasBegun);
 
 protected:
-    QString haventBegunDrawUserMessageMove () const override;
+    bool drawCreateMoreSelectionAndUpdateStatusBar(bool drawAcceptedAsDrag, const QPoint &accidentalDragAdjustedPoint, const QRect &normalizedRectIn) override;
 
+    //
+    // Move
+    //
 
 protected:
-    void setSelectionBorderForBeginDrawMove () override;
-
+    QString haventBegunDrawUserMessageMove() const override;
 
 protected:
-    QString nonSmearMoveCommandName () const override;
-
-
-//
-// Resize/Scale
-//
+    void setSelectionBorderForBeginDrawMove() override;
 
 protected:
-    QString haventBegunDrawUserMessageResizeScale () const override;
+    QString nonSmearMoveCommandName() const override;
 
+    //
+    // Resize/Scale
+    //
 
 protected:
-    void setSelectionBorderForBeginDrawResizeScale () override;
+    QString haventBegunDrawUserMessageResizeScale() const override;
 
+protected:
+    void setSelectionBorderForBeginDrawResizeScale() override;
 
-//
-// Select Text
-//
+    //
+    // Select Text
+    //
 
 private:
-    bool onSelectionToSelectText () const;
-
+    bool onSelectionToSelectText() const;
 
 private:
-    QString haventBegunDrawUserMessageSelectText () const;
-
-    void setCursorSelectText ();
+    QString haventBegunDrawUserMessageSelectText() const;
 
+    void setCursorSelectText();
 
 private:
-    void beginDrawSelectText ();
-
+    void beginDrawSelectText();
 
 protected:
-    virtual QVariant selectTextOperation (Operation op,
-        const QVariant &data1 = QVariant (), const QVariant &data2 = QVariant ());
+    virtual QVariant selectTextOperation(Operation op, const QVariant &data1 = QVariant(), const QVariant &data2 = QVariant());
 
-
-//
-// User Changing Text Style Elements
-//
+    //
+    // User Changing Text Style Elements
+    //
 
 protected:
-    bool shouldChangeTextStyle () const;
+    bool shouldChangeTextStyle() const;
 
     /**
      * Adds a kpToolTextChangeStyleCommand to commandHistory().
@@ -290,13 +237,10 @@ protected:
      *
      * You should only call this if shouldChangeTextStyle() returns true.
      */
-    void changeTextStyle (const QString &name,
-                          const kpTextStyle &newTextStyle,
-                          const kpTextStyle &oldTextStyle);
+    void changeTextStyle(const QString &name, const kpTextStyle &newTextStyle, const kpTextStyle &oldTextStyle);
 
 protected Q_SLOTS:
-    void slotIsOpaqueChanged (bool isOpaque) override;
-
+    void slotIsOpaqueChanged(bool isOpaque) override;
 
 protected:
     /**
@@ -305,28 +249,29 @@ protected:
      *
      * Re-implemented from kpTool.
      */
-    bool careAboutColorsSwapped () const override { return true; }
+    bool careAboutColorsSwapped() const override
+    {
+        return true;
+    }
 
 protected Q_SLOTS:
-    void slotColorsSwapped (const kpColor &newForegroundColor,
-                                    const kpColor &newBackgroundColor) override;
+    void slotColorsSwapped(const kpColor &newForegroundColor, const kpColor &newBackgroundColor) override;
 
-    void slotForegroundColorChanged (const kpColor &color) override;
-    void slotBackgroundColorChanged (const kpColor &color) override;
-    void slotColorSimilarityChanged (double, int) override;
+    void slotForegroundColorChanged(const kpColor &color) override;
+    void slotBackgroundColorChanged(const kpColor &color) override;
+    void slotColorSimilarityChanged(double, int) override;
 
 public Q_SLOTS:
-    void slotFontFamilyChanged (const QString &fontFamily, const QString &oldFontFamily);
-    void slotFontSizeChanged (int fontSize, int oldFontSize);
-    void slotBoldChanged (bool isBold);
-    void slotItalicChanged (bool isItalic);
-    void slotUnderlineChanged (bool isUnderline);
-    void slotStrikeThruChanged (bool isStrikeThru);
+    void slotFontFamilyChanged(const QString &fontFamily, const QString &oldFontFamily);
+    void slotFontSizeChanged(int fontSize, int oldFontSize);
+    void slotBoldChanged(bool isBold);
+    void slotItalicChanged(bool isItalic);
+    void slotUnderlineChanged(bool isUnderline);
+    void slotStrikeThruChanged(bool isStrikeThru);
 
-
-//
-// Text Cursor Calculations (all static, no mutations)
-//
+    //
+    // Text Cursor Calculations (all static, no mutations)
+    //
 
 protected:
     /**
@@ -337,9 +282,7 @@ protected:
      * @returns whether the cursor is currently on a word character
      *          (not a space).
      */
-    static bool CursorIsOnWordChar (const QList <QString> &textLines,
-        int cursorRow, int cursorCol);
-
+    static bool CursorIsOnWordChar(const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * @param textLines One or more lines of text.
@@ -350,8 +293,7 @@ protected:
      *          textLines (on the first character of the first line)
      *          i.e. when moveCursorLeft() won't do anything.
      */
-    static bool CursorIsAtStart (const QList <QString> &textLines,
-        int cursorRow, int cursorCol);
+    static bool CursorIsAtStart(const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * @param textLines One or more lines of text.
@@ -362,9 +304,7 @@ protected:
      *          textLines (after the last character of the last line)
      *          i.e. when moveCursorRight() won't do anything.
      */
-    static bool CursorIsAtEnd (const QList <QString> &textLines,
-        int cursorRow, int cursorCol);
-
+    static bool CursorIsAtEnd(const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Moves the given cursor position one character to the left, if
@@ -379,8 +319,7 @@ protected:
      *                  the current column of the cursor and modified on
      *                  return to indicate the new column.
      */
-    static void MoveCursorLeft (const QList <QString> &textLines,
-        int *cursorRow, int *cursorCol);
+    static void MoveCursorLeft(const QList<QString> &textLines, int *cursorRow, int *cursorCol);
 
     /**
      * Moves the given cursor position one character to the right, if
@@ -395,9 +334,7 @@ protected:
      *                  the current column of the cursor and modified on
      *                  return to indicate the new column.
      */
-    static void MoveCursorRight (const QList <QString> &textLines,
-        int *cursorRow, int *cursorCol);
-
+    static void MoveCursorRight(const QList<QString> &textLines, int *cursorRow, int *cursorCol);
 
     /**
      * Moves the row and column values, representing the current cursor
@@ -418,8 +355,7 @@ protected:
      *          Note: Attempting to moving left when cursorIsAtStart()
      *                may still be counted as a move.
      */
-    static int MoveCursorToWordStart (const QList <QString> &textLines,
-        int *cursorRow, int *cursorCol);
+    static int MoveCursorToWordStart(const QList<QString> &textLines, int *cursorRow, int *cursorCol);
 
     /**
      * Moves the row and column values, representing the current cursor
@@ -440,30 +376,28 @@ protected:
      *          Note: Attempting to moving right when cursorIsAtEnd()
      *                may still be counted as a move.
      */
-    static int MoveCursorToNextWordStart (const QList <QString> &textLines,
-        int *cursorRow, int *cursorCol);
+    static int MoveCursorToNextWordStart(const QList<QString> &textLines, int *cursorRow, int *cursorCol);
 
-
-//
-// Keyboard Events - Handling Arrow Keys
-//
-// These methods always:
-//
-// 1. Before doing anything, end the current shape (e.g. a text editing command or
-//    selection move command).  This is done for 2 reasons:
-//
-//    a) The user has interrupted the current command e.g. if I were to
-//       type some text, press an arrow key and then type text again, the two
-//       periods of text typing should be separate commands due to the arrow
-//       key interruption.
-//
-//    b) To simplify the code by avoiding interference with the current command
-//       esp. since commands do not expect the cursor to move in the middle.
-//
-// 2. Accept the event as it is always intended for the method.  This is even
-//    if the operation could not complete e.g. an attempt to move the cursor
-//    left when it is already at column 0.
-//
+    //
+    // Keyboard Events - Handling Arrow Keys
+    //
+    // These methods always:
+    //
+    // 1. Before doing anything, end the current shape (e.g. a text editing command or
+    //    selection move command).  This is done for 2 reasons:
+    //
+    //    a) The user has interrupted the current command e.g. if I were to
+    //       type some text, press an arrow key and then type text again, the two
+    //       periods of text typing should be separate commands due to the arrow
+    //       key interruption.
+    //
+    //    b) To simplify the code by avoiding interference with the current command
+    //       esp. since commands do not expect the cursor to move in the middle.
+    //
+    // 2. Accept the event as it is always intended for the method.  This is even
+    //    if the operation could not complete e.g. an attempt to move the cursor
+    //    left when it is already at column 0.
+    //
 protected:
     /**
      * Moves the text cursor up one character.  Accepts the key event @p e.
@@ -477,8 +411,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleUpKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleUpKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Moves the text cursor down one character.  Accepts the key event @p e.
@@ -492,8 +425,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleDownKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleDownKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Moves the text cursor left one character or if CTRL is held, one
@@ -508,8 +440,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleLeftKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleLeftKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Moves the text cursor right one character or if CTRL is held, one
@@ -524,9 +455,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleRightKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
-
+    void handleRightKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Moves the text cursor to the start of the line and if CTRL is held,
@@ -541,8 +470,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleHomeKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleHomeKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Moves the text cursor to after the last character of the current
@@ -558,32 +486,30 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleEndKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleEndKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
-
-//
-// Keyboard Events - Handling Typing Keys
-//
-// For each method, if the respective event was actually intended for the
-// method:
-//
-// 1. If the event will not be a NOP:
-//
-//        If the current command is not the same as what this method would produce,
-//        it starts a new one, ending the current one (using the addNew*Command()
-//        methods).  If the current command is the same, it simply extends the
-//        current command e.g. if the current command was a kpToolTextInsertCommand
-//        and the user typed another character of text, that character would just be
-//        added to that command.
-//
-// 2. Accept the event.  This is even if the operation could not complete e.g.
-//    an attempt backspace when the cursor is at column 0.
-//
-// If the event was not intended for the method (e.g. pressing CTRL, Caps Lock
-// or any other key that does not produce text, in handleTextTyped()), nothing
-// happens.
-//
+    //
+    // Keyboard Events - Handling Typing Keys
+    //
+    // For each method, if the respective event was actually intended for the
+    // method:
+    //
+    // 1. If the event will not be a NOP:
+    //
+    //        If the current command is not the same as what this method would produce,
+    //        it starts a new one, ending the current one (using the addNew*Command()
+    //        methods).  If the current command is the same, it simply extends the
+    //        current command e.g. if the current command was a kpToolTextInsertCommand
+    //        and the user typed another character of text, that character would just be
+    //        added to that command.
+    //
+    // 2. Accept the event.  This is even if the operation could not complete e.g.
+    //    an attempt backspace when the cursor is at column 0.
+    //
+    // If the event was not intended for the method (e.g. pressing CTRL, Caps Lock
+    // or any other key that does not produce text, in handleTextTyped()), nothing
+    // happens.
+    //
 protected:
     /**
      * Backspaces and if the active text editing command is not
@@ -607,8 +533,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleBackspaceKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleBackspaceKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Deletes and if the active text editing command is not
@@ -632,9 +557,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleDeleteKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
-
+    void handleDeleteKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Enters and if the active text editing command is not
@@ -650,9 +573,7 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleEnterKeyPress (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
-
+    void handleEnterKeyPress(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
     /**
      * Inserts the printable characters of e->text() and accepts the key
@@ -673,20 +594,18 @@ protected:
      *
      * Called by keyPressEvent().
      */
-    void handleTextTyped (QKeyEvent *e,
-        const QList <QString> &textLines, int cursorRow, int cursorCol);
+    void handleTextTyped(QKeyEvent *e, const QList<QString> &textLines, int cursorRow, int cursorCol);
 
-
-//
-// Keyboard Events
-//
+    //
+    // Keyboard Events
+    //
 
 protected:
     // Prevents actions with single letter/number shortcuts from eating
     // keystrokes while a text selection is active.  This is important
     // because the Tool Box actions default to single letter/number
     // shortcuts.
-    bool viewEvent (QEvent *e) override;
+    bool viewEvent(QEvent *e) override;
 
     /**
      * Handles key press events.
@@ -706,20 +625,17 @@ protected:
      * Re-implemented from kpAbstractSelectionTool.
      */
 
-    void keyPressEvent (QKeyEvent *e) override;
+    void keyPressEvent(QKeyEvent *e) override;
 
-
-//
-// Input Method Text Entry
-//
+    //
+    // Input Method Text Entry
+    //
 
 protected:
-    void inputMethodEvent (QInputMethodEvent *e) override;
-
+    void inputMethodEvent(QInputMethodEvent *e) override;
 
 private:
-    struct kpToolTextPrivate * const d;
+    struct kpToolTextPrivate *const d;
 };
 
-
-#endif  // KP_TOOL_TEXT_H
+#endif // KP_TOOL_TEXT_H
